/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.parquet.bytes;

import java.io.IOException;
import java.io.OutputStream;
import java.nio.ByteBuffer;

import org.apache.asterix.column.bytes.encoder.ParquetDeltaBinaryPackingValuesWriterForLong;
import org.apache.asterix.column.bytes.stream.out.AbstractBytesOutputStream;
import org.apache.asterix.column.bytes.stream.out.ByteBufferOutputStream;

/**
 * A wrapper for {@link BytesInput} which is used to concatenate multiple {@link AbstractBytesOutputStream}
 *
 * @see ParquetDeltaBinaryPackingValuesWriterForLong#getBytes() as an example
 */
public class AsterixParquetBytesInput extends BytesInput {
    private final AbstractBytesOutputStream outputStream;

    public AsterixParquetBytesInput(AbstractBytesOutputStream outputStream) {
        this.outputStream = outputStream;
    }

    @Override
    public final void writeAllTo(OutputStream outputStream) throws IOException {
        this.outputStream.writeTo(outputStream);
    }

    @Override
    void writeInto(ByteBuffer buffer) {
        ByteBufferOutputStream adapter = new ByteBufferOutputStream();
        adapter.reset(buffer);
        try {
            writeAllTo(adapter);
        } catch (IOException e) {
            throw new RuntimeException(e);
        }
    }

    @Override
    public final long size() {
        return outputStream.size();
    }
}
